@@ -1,5 +1,6 @@
 # Configure file, edit only the values of keys.
 # Read the docstring
+import json, os
 
 
 def config():
@@ -14,26 +15,7 @@ def config():
     return \
         {
             'black_list': [],
-            'html_code': """
-<!DOCTYPE html>
-<html lang="en">
-<head>
-    <meta charset="UTF-8">
-    <meta http-equiv="X-UA-Compatible" content="IE=edge">
-    <meta name="viewport" content="width=device-width, initial-scale=1.0">
-    <link rel="stylesheet" href="style.css">
-    <title></title>
-</head>
-<body>
-    <header></header>
-    <main>
-        
-    </main>
-    <footer></footer>
-
-    <script src="script.js"></script>
-</body>
-</html>""".strip(),
+            'html_code': """""",
             'css_code': """""",
             'js_code': """""",
         }
