@@ -18,10 +18,26 @@ def get_ext(file='', path=''):
         index = path.rfind('\\')
         return path[index+1:]
     else:
-        index = file.rfind('.')  # Getting the type of file
+        index = file.rfind('.')
         return file[index:].lower()
 
 
+def get_last(path):
+    if path.rfind('\\') != -1:
+        last = path[1+path.rfind('\\'):]
+    else:
+        last = path[1+path.rfind('/'):]
+    if last.rfind('"'):
+        last = last.replace('"', '')
+    return last
+
+
+def path_no_file(path):
+    filename = get_last(path)
+    return path.replace(filename, '')
+
+
+
 def get_file(path):
     if '\\' not in path:
         return path
@@ -40,8 +56,3 @@ def file_types():
                       'videos': ('.mp4', '.avi', '.wmv', '.mov', '.avchd')},
             'docs': ('.pdf', '.ppt', '.docx', '.txt', '.xls', '.doc')}
 
-
-
-
-
-
