@@ -1,17 +1,19 @@
-from click import group
+import click
 from lash.file_handler import *
 from lash.image_handler import *
+from lash.audio_handler import *
+from lash.video_handler import *
 from lash.app_math import *
 from lash.webTools import *
 from lash.ExtraTools import *
 
 
-@group('global')
+
+@click.group('global')
 def Global():
     """\b
-        - Lash 1.2.1 by KevBoyz ~ https://github.com/KevBoyz/Lash
+        - Lash 1.2.4 by KevBoyz ~ https://github.com/KevBoyz/Lash
     """
-    ...
 
 
 # Global Commands
@@ -21,6 +23,7 @@ Global.add_command(organize)
 Global.add_command(autoclick)
 Global.add_command(keyhold)
 Global.add_command(taskkiller)
+Global.add_command(monitor)
 
 # Groups declaration
 Global.add_command(sched)
@@ -29,5 +32,8 @@ Global.add_command(web)
 Global.add_command(Zip)
 Global.add_command(image)
 Global.add_command(calc)
+Global.add_command(yt)
+Global.add_command(video)
+Global.add_command(audio)
 
-Global()  #
+Global()
